from peek_core_search._private.PluginNames import searchTuplePrefix
from vortex.Tuple import Tuple, addTupleType, TupleField


@addTupleType
class SearchResultObjectRouteTuple(Tuple):
    """Import Search Object Route

    This tuple is used to import object routes into the search plugin

    """

    __tupleType__ = searchTuplePrefix + "SearchResultObjectRouteTuple"

    #:  The title of the route, that the user will see
    title: str = TupleField()

    #:  The route that the angular app will route to
    path: str = TupleField()



import logging
from typing import Union

from twisted.internet.defer import Deferred, inlineCallbacks

from peek_core_search._private.client.controller.SearchObjectCacheController import (
    SearchObjectCacheController,
)
from peek_core_search._private.tuples.search_object.SearchObjectUpdateDateTuple import (
    SearchObjectUpdateDateTuple,
)
from vortex.Payload import Payload
from vortex.TupleSelector import TupleSelector
from vortex.handler.TupleDataObservableHandler import TuplesProviderABC

logger = logging.getLogger(__name__)


class ClientSearchObjectUpdateDateTupleProvider(TuplesProviderABC):
    def __init__(self, cacheHandler: SearchObjectCacheController):
        self._cacheHandler = cacheHandler

    @inlineCallbacks
    def makeVortexMsg(
        self, filt: dict, tupleSelector: TupleSelector
    ) -> Union[Deferred, bytes]:
        tuple_ = SearchObjectUpdateDateTuple()
        tuple_.updateDateByChunkKey = {
            key: self._cacheHandler.encodedChunk(key).lastUpdate
            for key in self._cacheHandler.encodedChunkKeys()
        }
        payload = Payload(filt, tuples=[tuple_])
        payloadEnvelope = yield payload.makePayloadEnvelopeDefer()
        vortexMsg = yield payloadEnvelope.toVortexMsg()
        return vortexMsg



from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler
from .EditSearchObjectTypeHandler import makeSearchObjectTypeHandler
from .EditSearchPropertyHandler import makeSearchPropertyHandler
from .SettingPropertyHandler import makeSettingPropertyHandler


def makeAdminBackendHandlers(
    tupleObservable: TupleDataObservableHandler, dbSessionCreator
):
    yield makeSearchPropertyHandler(tupleObservable, dbSessionCreator)
    yield makeSearchObjectTypeHandler(tupleObservable, dbSessionCreator)

    yield makeSettingPropertyHandler(dbSessionCreator)



import logging
from typing import List

from twisted.internet.defer import inlineCallbacks

from peek_core_search._private.worker.tasks.ImportSearchObjectTask import (
    importSearchObjectTask,
    removeSearchObjectTask,
)

logger = logging.getLogger(__name__)


class SearchObjectImportController:
    def __init__(self):
        pass

    def shutdown(self):
        pass

    @inlineCallbacks
    def importSearchObjects(self, searchObjectsEncodedPayload: bytes):
        yield importSearchObjectTask.delay(searchObjectsEncodedPayload)

    @inlineCallbacks
    def removeSearchObjects(self, importGroupHashes: List[str]):
        yield removeSearchObjectTask.delay(importGroupHashes)
